@@ -19,12 +19,12 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = ( 'digest', 'packages' );
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 
 
 my @deb_files = ();
 my $url_base = 'https://api.metacpan.org/source';
-my $stash = '$ENV{HOME}/tmp/.repo';
+my $stash = "$ENV{HOME}/tmp/.repo";
 
 sub init {
     unless( -d "$ENV{HOME}/tmp/.repo" ){
@@ -56,9 +56,12 @@ my $digest = sub {
 my $content = sub {
     my( $dir, $file ) = @_;
     my @control = ();
+
+    mkpath("$stash/tmp");
     if($file =~ /\.deb/){
+        my $file_size = -s "$dir/$file";
         copy("$dir/$file", "$stash/tmp");
-        system("cd $stash/tmp && perl -I $stash $stash/ar -x $file && tar -xf control.tar.gz");
+        system("cd $stash/tmp && perl -I$stash $stash/ar -x $file && tar -xf control.tar.gz");
         open(my $fh,"<","$stash/tmp/control") || die "cant open $stash/tmp/control: $!";
         system("rm -rf $stash/tmp/*");
         while(<$fh>){
@@ -66,12 +69,15 @@ my $content = sub {
             chomp;
             push @control, $_;
         }
+        push @control, 'Size: ' . $file_size;
+        push @control, 'Filename: ' . "deb/$file"; 
         push @control, 'MD5sum: ' . $digest->("$dir/$file")->{'md5'};
         push @control, 'SHA1: ' . $digest->("$dir/$file")->{'sha1'};
         push @control, 'SHA256: ' . $digest->("$dir/$file")->{'sha256'};
         push @control, "\n";
         return \@control;
-    } else { die "no deb file" }
+    }
+    #} else { warn "no deb file" }
 };
 
 my $find_deb = sub {
